==> apache-camel-3.4.1-src.zip: apache-camel-3.4.1/components/camel-bindy/src/test/java/org/apache/camel/dataformat/bindy/model/complex/generateheader/Client.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.dataformat.bindy.model.complex.generateheader;

import org.apache.camel.dataformat.bindy.annotation.DataField;
import org.apache.camel.dataformat.bindy.annotation.Link;

@Link
public class Client {

    @DataField(pos = 2, columnName = "Client Nr")
    private String clientNr;

    @DataField(pos = 3, columnName = "First Name")
    private String firstName;

    @DataField(pos = 4, columnName = "Last Name")
    private String lastName;

    public String getClientNr() {
        return clientNr;
    }

    public void setClientNr(String clientNr) {
        this.clientNr = clientNr;
    }

    public String getFirstName() {
        return firstName;
    }

    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    public String getLastName() {
        return lastName;
    }

    public void setLastName(String lastName) {
        this.lastName = lastName;
    }

    @Override
    public String toString() {
        return "Model : " + Client.class.getName() + " : " + String.valueOf(this.clientNr) + ", " + String.valueOf(this.firstName) + ", " + String.valueOf(this.lastName);
    }

}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/components/camel-bindy/src/test/java/org/apache/camel/dataformat/bindy/model/complex/generateheader/Client.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.dataformat.bindy.model.complex.generateheader;

import org.apache.camel.dataformat.bindy.annotation.DataField;
import org.apache.camel.dataformat.bindy.annotation.Link;

@Link
public class Client {

    @DataField(pos = 2, columnName = "Client Nr")
    private String clientNr;

    @DataField(pos = 3, columnName = "First Name")
    private String firstName;

    @DataField(pos = 4, columnName = "Last Name")
    private String lastName;

    public String getClientNr() {
        return clientNr;
    }

    public void setClientNr(String clientNr) {
        this.clientNr = clientNr;
    }

    public String getFirstName() {
        return firstName;
    }

    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    public String getLastName() {
        return lastName;
    }

    public void setLastName(String lastName) {
        this.lastName = lastName;
    }

    @Override
    public String toString() {
        return "Model : " + Client.class.getName() + " : " + String.valueOf(this.clientNr) + ", "
               + String.valueOf(this.firstName) + ", " + String.valueOf(this.lastName);
    }

}
